@@ -1,11 +1,9 @@
-context("Rendering HTML blocks")
-
 test_that("the `render_block_title()` function returns the expected output", {
 
   # Create a title block
   block_title <- blocks(block_title("Test Title"))
 
-  snapshot(block_title)
+  expect_snapshot(block_title)
 })
 
 test_that("the `render_block_text()` function returns the expected output", {
@@ -13,7 +11,7 @@ test_that("the `render_block_text()` function returns the expected output", {
   # Create a text block
   block_text <- blocks(block_text("Test Text"))
 
-  snapshot(block_text)
+  expect_snapshot(block_text)
 })
 
 test_that("the `render_block_articles()` function returns the expected output", {
@@ -28,6 +26,8 @@ test_that("the `render_block_articles()` function returns the expected output",
       )
     )
 
+  expect_snapshot(block_articles_1)
+
   # Create an articles block with two articles
   block_articles_2 <-
     block_articles(
@@ -43,6 +43,8 @@ test_that("the `render_block_articles()` function returns the expected output",
       )
     )
 
+  expect_snapshot(block_articles_2)
+
   # Create an articles block with three articles
   block_articles_3 <-
     block_articles(
@@ -63,9 +65,7 @@ test_that("the `render_block_articles()` function returns the expected output",
       )
     )
 
-  snapshot(block_articles_1)
-  snapshot(block_articles_2)
-  snapshot(block_articles_3)
+  expect_snapshot(block_articles_3)
 })
 
 test_that("the social link functions work correctly", {
@@ -73,7 +73,7 @@ test_that("the social link functions work correctly", {
   social_link_1 <-
     social_link(service = "Dribbble", link = "https://dribbble.com")
 
-  snapshot(social_link_1)
+  expect_snapshot(social_link_1)
 
   # Expect that the `social_service_icons()` function
   # returns a tibble
